
/**
 * Beschreibt eine Uhr
 * 
 * @author Albert Wiedemann
 * @version 1.0
 */
class Uhr
{
    /** Name des Sensors */
    private String name;
    /** aktueller Wert der Zeit, Stunden */
    private int stunden;
    /** aktueller Wert der Zeit, minuten */
    private int minuten;
    /** aktueller Wert der Zeit, Sekunden */
    private int sekunden;
    /** Rollladen, dem Änderungen gemeldet werden */
    private Rollladen beobachter;
    
    /**
     * Legt den Namen und den Beobachter fest.
     * @param namensZusatz individualler Namensteil des Sensors
     * @param beobachter wird von jeder Wertänderung benachrichtigt
     */
    Uhr(String namensZusatz)
    {
        name = "Uhr" + namensZusatz;
        beobachter = null;
        stunden = 0;
        minuten = 0;
        sekunden = 0;
    }
    
    /**
     * Meldet den Namen des Geräts zurück
     * @return Name
     */
    String NameGeben()
    {
        return name;
    }
    
    /**
     * Registriert einen Beobachter
     * @param beobachter wird von jeder Wertänderung benachrichtigt
     */
    void BeobachterRegistrieren (Rollladen beobachter)
    {
        this.beobachter = beobachter;
    }

    /**
     * Setzt den neuen Sensorwert
     * @param stunden der neue Wert für die Stunde
     */
    void WertSetzen (int stunden)
    {
        if ((stunden >= 0) && (stunden < 24))
        {
            this.stunden = stunden;
            beobachter.WertänderungMeldenUhr(stunden*10000 + minuten*100 + sekunden);
        }
    }
    
    /**
     * Meldet den Zustand der Uhr
     * @return Zustand als Zeichenkette
     */
    String ZustandGeben()
    {
        return "" + stunden + ":" + (minuten < 10 ? "0" + minuten : "" + minuten) + ":" + (sekunden < 10 ? "0" + sekunden : "" + sekunden) + "Uhr";
    }
}
